pushover

package
v1.2.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 15, 2023 License: Unlicense Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Emergency

func Emergency(messageTitle string, messageBody string)

The function "Emergency" sends an emergency message with a specified title and body using the Pushover service.

func High

func High(messageTitle string, messageBody string)

The High function sends a high priority message with a title and body to a recipient using the Pushover service.

func Low

func Low(messageTitle string, messageBody string)

The Low function sends a low priority push notification with a given title and body.

func Normal

func Normal(messageTitle string, messageBody string)

The Normal function sends a push notification with a normal priority level.

func WithURL

func WithURL(messageTitle string, messageBody string, url string)

The function "WithURL" sends a push notification with a message title, message body, and a URL to a recipient using the Pushover service.

Types

This section is empty.

Jump to