Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Emergency ¶
The function "Emergency" sends an emergency message with a specified title and body using the Pushover service.
func High ¶
The High function sends a high priority message with a title and body to a recipient using the Pushover service.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.